<?php

/**
 * Page centrale de gestion des paramètres d'un utilisateur et du portail lui-même.
 */

 require_once ($_SERVER["DOCUMENT_ROOT"]."/services/fonctions/bdd/utilisateurs.php");
 
 $liste_utilisateurs = listeUtilisateursPostfix($pdo);
 $prefixe_utilisateur = retournePrefixeUtilisateurPostfix($pdo,$_SESSION['pseudo_utilisateur']);
 
/**
* Affiche le formulaire de selection d'un utilisateur si celui connecté possède les privilèges administrateur.
*/
if (testPrivileges()=="administrateur") {
	echo <<<_HEREDOC_
<div class="row">
	<div class="col-12 col-md-6">
		<div class="card  mt-4">
			<div class="card-body">
				<h5 class="card-title">Choix de l'adresse</h5>
				<form id="form_choix_utilisateur" action="/services/traitements/utilisateurs/changeUtilisateur.php" method="post">
					<select class="form-select" name="choix_utilisateur" onchange="autoSoumission(this);">
_HEREDOC_;

				/**
				 * Remplis un menu déroulant permettant le choix de l'utilisateur par l'administrateur.
				 * Ce choix permettra de modifier les données y étant rattachés.
				 * La valeur par défaut du menu est positionnée sur le compte administrateur actuellement connecté.
				 */
				foreach ($liste_utilisateurs as $utilisateur_bdd => $utilisateur) {
					if ($utilisateur['utilisateur']==$_SESSION['pseudo_utilisateur']) {
						echo "<option value=\"".$utilisateur['utilisateur']."\" selected>".$utilisateur['utilisateur']."</option>\n";
					}
					elseif ($_SESSION['privilege_utilisateur']=="administrateur") {
						echo "<option value=\"".$utilisateur['utilisateur']."\">".$utilisateur['utilisateur']."</option>\n";
					}
				}

				echo <<<_HEREDOC_
					</select>
					<input type="hidden" name="page_origine" value="parametres">
				</form>
			</div>
		</div>
	</div>
_HEREDOC_;
}

/**
* Changement du mot de passe d'un utilisateur.
*/

?>
	<div class="col-12 col-md-6">
		<div class="card mt-4">
			<div class="card-body">
				<h5 class="card-title">Mot de passe</h5>
				<form action="/services/traitements/utilisateurs/changeMotDePasseUtilisateur.php" method="post">
					<div class="input-group">
						<?php if ($_SESSION['privilege_utilisateur']=="utilisateur") { echo '<input type="password" class="form-control" name="ancien_mot_de_passe" placeholder="Ancien mot de passe" required>'; } ?>
						<input type="password" class="form-control" name="nouveau_mot_de_passe" placeholder="Nouveau mot de passe" required>
						<input type="password" class="form-control" name="confirmation_mot_de_passe" placeholder="Confirmation mot de passe" required>
						<button class="btn btn-primary bouton-ajout" type="submit"><img src="/fichiers/svg/plus.svg"/></button>
					</div>
				</form>
			</div>
		</div>
	</div>
</div>

<?php

if ($_SESSION['privilege_utilisateur']=="administrateur") {
	echo <<<_HEREDOC_
	<h5>Préfixe</h5>
	<p>Préfixe actuel de {$_SESSION['pseudo_utilisateur']} : {$prefixe_utilisateur}</p>
	<form action="/services/traitements/utilisateurs/changePrefixeUtilisateur.php" method="post">
		<input type="text" name="nouveau_prefixe" placeholder="Nouveau prefixe">
		<button class="btn btn-primary bouton-ajout" type="submit"><img src="/fichiers/svg/plus.svg"/></button>
	</form>
_HEREDOC_;
}

echo <<<_HEREDOC_
<h5>Sauvegarde et restauration des données</h5>
<p>Sauvegarde</p>
<p>Sauvegarde des alias virtuels de l'utilisateur</p>
<form action="/services/traitements/import_export/exportAliasVirtuelsUtilisateur.php" method="post">
	<button class="btn btn-primary bouton-ajout" type="submit"><img src="/fichiers/svg/plus.svg"/></button>
</form>
_HEREDOC_;

if ($_SESSION['privilege_utilisateur']=="administrateur") {
 echo <<<_HEREDOC_
 <p>Sauvegarde de la base de données</p>
 <form action="/services/traitements/import_export/exportDonneesBdd.php" method="post">
  <label>Alias virtuels :</label>
  <input type="checkbox" name="export_alias_virtuels" checked>
  <label>Domaines :</label>
  <input type="checkbox" name="export_domaines" checked>
  <label>Liste noire destinataires :</label>
  <input type="checkbox" name="export_liste_noire_destinataires" checked>
  <label>Liste noire expéditeurs :</label>
  <input type="checkbox" name="export_liste_noire_expediteurs" checked>
  <label>Utilisateurs :</label>
  <input type="checkbox" name="export_utilisateurs" checked>
  <button class="btn btn-primary bouton-ajout" type="submit"><img src="/fichiers/svg/plus.svg"/></button>
 </form>
_HEREDOC_;
}

echo <<<_HEREDOC_
<p>Restauration</p>
<p>Restauration des alias virtuels de l'utilisateur</p>
<form action="/services/traitements/import_export/importAliasVirtuelsUtilisateur.php" method="post" enctype="multipart/form-data">
 <input type="file" name="import_alias_virtuels_csv">
 <i>Les doublons seront omis.</i>
	<button class="btn btn-primary bouton-ajout" type="submit"><img src="/fichiers/svg/plus.svg"/></button>
</form>
_HEREDOC_;

if ($_SESSION['privilege_utilisateur']=="administrateur") {
 echo <<<_HEREDOC_
 <p>Restauration de la base de données</p>
 <p>Attention, toutes les données non sauvegardés dans chaque section sélectionnée et présente dans votre fichier de restauration seront écrasées !</p>
 <form action="/services/traitements/import_export/importDonneesBdd.php" method="post" enctype="multipart/form-data">
  <input type="file" name="import_donnees_csv">
  <label>Alias virtuels :</label>
  <input type="checkbox" name="import_alias_virtuels">
  <label>Domaines :</label>
  <input type="checkbox" name="import_domaines">
  <label>Liste noire destinataires :</label>
  <input type="checkbox" name="import_liste_noire_destinataires">
  <label>Liste noire expéditeurs :</label>
  <input type="checkbox" name="import_liste_noire_expediteurs">
  <label>Utilisateurs :</label>
  <input type="checkbox" name="import_utilisateurs">
  <button class="btn btn-primary bouton-ajout" type="submit"><img src="/fichiers/svg/plus.svg"/></button>
 </form>
_HEREDOC_;
}

?>

<script src="/fichiers/js/filtre.js"></script>